@@ -51,6 +51,7 @@
  */
 
 #include <config.h>
+#include <ctype.h>
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
@@ -949,7 +950,7 @@ dlz_allowzonexfr(void *dbdata, const char *name,
 	isc_result_t result;
 
 	/* check to see if we are authoritative for the zone first */
-	result = dlz_findzonedb(dbdata, name);
+	result = dlz_findzonedb(dbdata, name, NULL, NULL);
 	if (result != ISC_R_SUCCESS) {
 		return (result);
 	}
@@ -974,7 +975,9 @@ dlz_authority(const char *zone, void *dbdata,
 }
 
 isc_result_t
-dlz_findzonedb(void *dbdata, const char *name) {
+dlz_findzonedb(void *dbdata, const char *name,
+		dns_clientinfomethods_t *methods,
+		dns_clientinfo_t *clientinfo) {
 	char *_suffix = ((ldap_instance_t *)dbdata)->enum_suffix;
 	const char *_name = name;
 	int d;
